@@ -15,7 +15,7 @@ except:
 # In[3]:
 
 
-version = '0.54'
+version = '0.55'
 
 import re
 import tempfile
@@ -462,26 +462,9 @@ if is_testing():
         print(pklread(pkl_path))
 
 
-# In[ ]:
-
-
-for p in [
-    #"gs://srfl-data/DIV2K-te_X8.pklv4",
-    #"gs://srfl-data/DIV2K-te_X4.pklv4",
-    #"gs://srfl-data/DIV2K-te.pklv4",
-    "gs://srfl-data/CelebAHq_160_MBic_te_X16.pklv4",
-    "gs://srfl-data/CelebAHq_160_MBic_te_X8.pklv4",
-    "gs://srfl-data/CelebAHq_160_MBic_te_X4.pklv4",
-    "gs://srfl-data/CelebAHq_160_MBic_te.pklv4"
-    ]:
-    l = pklread(p)
-    l = l[:int(np.ceil(len(l)*0.1))]
-    pklwrite(p.replace(".pklv4", "_10pct.pklv4"), l)
-
-
 # # Images
 
-# In[ ]:
+# In[43]:
 
 
 def imread(path):
@@ -515,7 +498,7 @@ def impad(img, top=0, bottom=0, left=0, right=0, color=255):
     return np.pad(img, [(top, bottom), (left, right), (0, 0)], 'constant', constant_values=color)
 
 
-# In[ ]:
+# In[44]:
 
 
 def imshow(array, scale=1):
@@ -530,7 +513,7 @@ def imshow(array, scale=1):
         cv2.waitKey()
 
 
-# In[ ]:
+# In[45]:
 
 
 if is_testing():
@@ -538,14 +521,14 @@ if is_testing():
     imshow(img)
 
 
-# In[ ]:
+# In[46]:
 
 
 if is_testing():
     imshow('http://via.placeholder.com/70.png')
 
 
-# In[ ]:
+# In[47]:
 
 
 def imscaleNN(img, s):
@@ -555,7 +538,7 @@ def imscaleBic(img, s):
     return cv2.resize(img, None, fx=s, fy=s, interpolation=cv2.INTER_CUBIC)
 
 
-# In[ ]:
+# In[48]:
 
 
 if is_testing():
@@ -574,7 +557,7 @@ if is_testing():
         imshow(out_large_interbic)
 
 
-# In[ ]:
+# In[49]:
 
 
 def imRepeat(img, height, width):
@@ -588,7 +571,7 @@ def imRepeat(img, height, width):
     return img
 
 
-# In[ ]:
+# In[50]:
 
 
 if is_testing():
@@ -596,33 +579,33 @@ if is_testing():
     imshow(imRepeat(img_random_color_3x5, 7, 11), scale=10)
 
 
-# In[ ]:
+# In[51]:
 
 
 def imNewWhite(height, width):
     return np.ones((height, width, 3)).astype(np.uint8) * 255
 
 
-# In[ ]:
+# In[52]:
 
 
 if is_testing(): imshow(imNewWhite(10, 500) - 30)
 
 
-# In[ ]:
+# In[53]:
 
 
 def imNewBlack(height, width):
     return np.zeros((height, width, 3)).astype(np.uint8)
 
 
-# In[ ]:
+# In[54]:
 
 
 if is_testing(): imshow(imNewBlack(10, 500))
 
 
-# In[ ]:
+# In[55]:
 
 
 def imAddNoiseGauss(img, std):
@@ -634,7 +617,7 @@ def imAddNoiseGauss(img, std):
 if is_testing(): imshow(imAddNoiseGauss(imread('http://via.placeholder.com/150.png'), 10))
 
 
-# In[ ]:
+# In[56]:
 
 
 def imJpgDegradation(img, quality):
@@ -647,7 +630,7 @@ def imJpgDegradation(img, quality):
 if is_testing(): imshow(imJpgDegradation(imread('http://via.placeholder.com/150.png'), 15))
 
 
-# In[ ]:
+# In[57]:
 
 
 def imCropCenter(img, size):
@@ -662,35 +645,35 @@ def imCropCenter(img, size):
     return img[h_start:h_end, w_start:w_end]
 
 
-# In[ ]:
+# In[58]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 10))
 
 
-# In[ ]:
+# In[59]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 49))
 
 
-# In[ ]:
+# In[60]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 50))
 
 
-# In[ ]:
+# In[61]:
 
 
 if is_testing(): 
     imshow(imCropCenter(imread('http://via.placeholder.com/40.png'), 100))
 
 
-# In[ ]:
+# In[62]:
 
 
 def imGallery(imgs, pad=0):
@@ -721,7 +704,7 @@ def imGallery(imgs, pad=0):
     return out
 
 
-# In[ ]:
+# In[63]:
 
 
 if is_testing():
@@ -729,49 +712,49 @@ if is_testing():
     listOfDummyImagesBlackToWhite = [imNewBlack(10, 10) + 25 * i for i in range(10)]
 
 
-# In[ ]:
+# In[64]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:1]))
 
 
-# In[ ]:
+# In[65]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2]))
 
 
-# In[ ]:
+# In[66]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:2], pad=1))
 
 
-# In[ ]:
+# In[67]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:5], pad=1))
 
 
-# In[ ]:
+# In[68]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:9], pad=1))
 
 
-# In[ ]:
+# In[69]:
 
 
 if is_testing():
     imshow(imGallery(listOfDummyImagesBlackToWhite[:10], pad=1))
 
 
-# In[ ]:
+# In[70]:
 
 
 if is_testing():
@@ -781,14 +764,14 @@ if is_testing():
 
 # # Files
 
-# In[ ]:
+# In[71]:
 
 
 def fiFindByWildcard(wildcard):
     return natsort.natsorted(glob.glob(wildcard, recursive=True))
 
 
-# In[ ]:
+# In[72]:
 
 
 if is_testing():
@@ -817,7 +800,7 @@ if is_testing():
         imshow(imGallery(imgs))
 
 
-# In[ ]:
+# In[73]:
 
 
 def fiRemove(path):
@@ -845,7 +828,7 @@ def fiAgeHours(path):
     return (time.time() - os.stat(path)[stat.ST_MTIME]) / 3600
 
 
-# In[ ]:
+# In[74]:
 
 
 if is_testing():
@@ -879,7 +862,7 @@ if is_testing():
 
 # # Jupyter
 
-# In[ ]:
+# In[75]:
 
 
 def jnNbFullWidth():
@@ -893,7 +876,7 @@ def jnPandasSettings():
     pd.set_option('display.max_colwidth', None)
 
 
-# In[ ]:
+# In[76]:
 
 
 def jnImageRenderingPixelated():
@@ -905,7 +888,7 @@ def jnImageRenderingAuto():
     display(HTML('<style type = text/css> img { image-rendering: auto; } </style>'))
 
 
-# In[ ]:
+# In[77]:
 
 
 def jnDefault():
@@ -917,7 +900,7 @@ if is_testing():
     jnDefault()
 
 
-# In[ ]:
+# In[78]:
 
 
 def jnHtmlRow(strList, width=100):
@@ -930,7 +913,7 @@ if is_testing():
     
 
 
-# In[ ]:
+# In[79]:
 
 
 def jnImgToHtmlB64(img):
@@ -942,11 +925,14 @@ def jnImgToHtmlB64(img):
 
 #def jnHtmlImgsRow(imgs, names=None):
 
-def jnImageRow(imgs, names=None, width=100):
+def jnImageRow(imgs, names=None, width=100, external=False):
     _row = lambda x: '<tr>' + x + '</tr>'
     _col = lambda x: '<td style="text-align:center">' + x + '</td>'
     _cols = lambda x: "".join(map(_col, x))
-    _imcols = lambda x: "".join(map(_col, map(jnImgToHtmlB64, x)))
+    if external:
+        _imcols = lambda x: "".join(map(_col, map(lambda y: '<img src="{}" style="display:block; margin:0 auto;">'.format(y), x)))
+    else:
+        _imcols = lambda x: "".join(map(_col, map(jnImgToHtmlB64, x)))
     _tab = lambda x: '<table width="{width}%">'.format(width=width) + x + '</table>'
     
     header = "" if names is None else _row(_cols(names))
@@ -954,7 +940,7 @@ def jnImageRow(imgs, names=None, width=100):
     display(HTML(html))
 
 
-# In[ ]:
+# In[80]:
 
 
 if is_testing():
@@ -962,7 +948,14 @@ if is_testing():
    
 
 
-# In[ ]:
+# In[81]:
+
+
+if is_testing():
+    jnImageRow(imgs=["http://via.placeholder.com/40x20.png", "http://via.placeholder.com/40x20.png"], names=["a", "b"], external=True)
+
+
+# In[82]:
 
 
 
@@ -972,7 +965,7 @@ if is_testing():
 
 # # Shell
 
-# In[ ]:
+# In[83]:
 
 
 def shell(cmd):
@@ -987,7 +980,7 @@ def shell(cmd):
 
 # # GIT
 
-# In[ ]:
+# In[84]:
 
 
 def gitGetHash():
@@ -997,7 +990,7 @@ if is_testing():
     print(gitGetHash())
 
 
-# In[ ]:
+# In[85]:
 
 
 def gitGetBranch():
@@ -1007,7 +1000,7 @@ if is_testing():
     print(gitGetBranch())
 
 
-# In[ ]:
+# In[86]:
 
 
 def gitGetMessage():
@@ -1017,7 +1010,7 @@ if is_testing():
     print(gitGetMessage())
 
 
-# In[ ]:
+# In[87]:
 
 
 def gitGetAllFiles():
@@ -1027,7 +1020,7 @@ if is_testing():
     print(gitGetAllFiles())
 
 
-# In[ ]:
+# In[88]:
 
 
 def gitListByTime(path=None):
@@ -1043,7 +1036,7 @@ if is_testing():
     print(gitListByTime()[-3:])
 
 
-# In[ ]:
+# In[89]:
 
 
 def shellSortDirsBySize():
@@ -1055,14 +1048,14 @@ if is_testing():
 
 # # Package Files
 
-# In[ ]:
+# In[90]:
 
 
 if is_testing():
     package_files = {}
 
 
-# In[ ]:
+# In[91]:
 
 
 def shell(cmd):
@@ -1070,7 +1063,7 @@ def shell(cmd):
     return result.stdout.decode()
 
 
-# In[ ]:
+# In[92]:
 
 
 if is_testing():
@@ -1102,7 +1095,7 @@ setup(
 )""".format(requirements=", ".join(["'" + r + "'" for r in requirements]), version=version)
 
 
-# In[ ]:
+# In[93]:
 
 
 if is_testing():
@@ -1112,7 +1105,7 @@ description-file = README.md
 """
 
 
-# In[ ]:
+# In[94]:
 
 
 if is_testing():
@@ -1135,7 +1128,7 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE."""
 
 
-# In[ ]:
+# In[95]:
 
 
 if is_testing():
